@@ -16,8 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Natural Language Hook."""
-from typing import Optional, Sequence, Tuple, Union
+from __future__ import annotations
 
+from typing import Sequence
+
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.language_v1 import LanguageServiceClient, enums
 from google.cloud.language_v1.types import (
@@ -56,8 +59,8 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -71,20 +74,19 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         Retrieves connection to Cloud Natural Language service.
 
         :return: Cloud Natural Language service object
-        :rtype: google.cloud.language_v1.LanguageServiceClient
         """
         if not self._conn:
-            self._conn = LanguageServiceClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
+            self._conn = LanguageServiceClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._conn
 
     @GoogleBaseHook.quota_retry()
     def analyze_entities(
         self,
-        document: Union[dict, Document],
-        encoding_type: Optional[enums.EncodingType] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        document: dict | Document,
+        encoding_type: enums.EncodingType | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> AnalyzeEntitiesResponse:
         """
         Finds named entities in the text along with entity types,
@@ -98,7 +100,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
         :param metadata: Additional metadata that is provided to the method.
-        :rtype: google.cloud.language_v1.types.AnalyzeEntitiesResponse
         """
         client = self.get_conn()
 
@@ -109,11 +110,11 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def analyze_entity_sentiment(
         self,
-        document: Union[dict, Document],
-        encoding_type: Optional[enums.EncodingType] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        document: dict | Document,
+        encoding_type: enums.EncodingType | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> AnalyzeEntitySentimentResponse:
         """
         Finds entities, similar to AnalyzeEntities in the text and analyzes sentiment associated with each
@@ -127,7 +128,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
         :param metadata: Additional metadata that is provided to the method.
-        :rtype: google.cloud.language_v1.types.AnalyzeEntitiesResponse
         """
         client = self.get_conn()
 
@@ -138,11 +138,11 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def analyze_sentiment(
         self,
-        document: Union[dict, Document],
-        encoding_type: Optional[enums.EncodingType] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        document: dict | Document,
+        encoding_type: enums.EncodingType | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> AnalyzeSentimentResponse:
         """
         Analyzes the sentiment of the provided text.
@@ -155,7 +155,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
         :param metadata: Additional metadata that is provided to the method.
-        :rtype: google.cloud.language_v1.types.AnalyzeSentimentResponse
         """
         client = self.get_conn()
 
@@ -166,11 +165,11 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def analyze_syntax(
         self,
-        document: Union[dict, Document],
-        encoding_type: Optional[enums.EncodingType] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        document: dict | Document,
+        encoding_type: enums.EncodingType | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> AnalyzeSyntaxResponse:
         """
         Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part
@@ -184,7 +183,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
         :param metadata: Additional metadata that is provided to the method.
-        :rtype: google.cloud.language_v1.types.AnalyzeSyntaxResponse
         """
         client = self.get_conn()
 
@@ -195,12 +193,12 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def annotate_text(
         self,
-        document: Union[dict, Document],
-        features: Union[dict, AnnotateTextRequest.Features],
+        document: dict | Document,
+        features: dict | AnnotateTextRequest.Features,
         encoding_type: enums.EncodingType = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> AnnotateTextResponse:
         """
         A convenience method that provides all the features that analyzeSentiment,
@@ -216,7 +214,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
         :param metadata: Additional metadata that is provided to the method.
-        :rtype: google.cloud.language_v1.types.AnnotateTextResponse
         """
         client = self.get_conn()
 
@@ -232,10 +229,10 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     @GoogleBaseHook.quota_retry()
     def classify_text(
         self,
-        document: Union[dict, Document],
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        document: dict | Document,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> ClassifyTextResponse:
         """
         Classifies a document into categories.
@@ -247,7 +244,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
         :param metadata: Additional metadata that is provided to the method.
-        :rtype: google.cloud.language_v1.types.ClassifyTextResponse
         """
         client = self.get_conn()
 
