@@ -15,17 +15,12 @@
 # specific language governing permissions and limitations
 # under the License.
 """Handler that integrates with Stackdriver"""
+from __future__ import annotations
+
 import logging
-import sys
-from typing import Collection, Dict, List, Optional, Tuple, Type, Union
+from typing import Collection
 from urllib.parse import urlencode
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
-from google.api_core.gapic_v1.client_info import ClientInfo
 from google.auth.credentials import Credentials
 from google.cloud import logging as gcp_logging
 from google.cloud.logging import Resource
@@ -33,9 +28,10 @@ from google.cloud.logging.handlers.transports import BackgroundThreadTransport,
 from google.cloud.logging_v2.services.logging_service_v2 import LoggingServiceV2Client
 from google.cloud.logging_v2.types import ListLogEntriesRequest, ListLogEntriesResponse
 
-from airflow import version
+from airflow.compat.functools import cached_property
 from airflow.models import TaskInstance
 from airflow.providers.google.cloud.utils.credentials_provider import get_credentials_and_project_id
+from airflow.providers.google.common.consts import CLIENT_INFO
 
 DEFAULT_LOGGER_NAME = "airflow"
 _GLOBAL_RESOURCE = Resource(type="global", labels={})
@@ -61,24 +57,18 @@ class StackdriverTaskHandler(logging.Handler):
         If omitted, authorization based on `the Application Default Credentials
         <https://cloud.google.com/docs/authentication/production#finding_credentials_automatically>`__ will
         be used.
-    :type gcp_key_path: str
     :param scopes: OAuth scopes for the credentials,
-    :type scopes: Sequence[str]
     :param name: the name of the custom log in Stackdriver Logging. Defaults
         to 'airflow'. The name of the Python logger will be represented
         in the ``python_logger`` field.
-    :type name: str
     :param transport: Class for creating new transport objects. It should
         extend from the base :class:`google.cloud.logging.handlers.Transport` type and
         implement :meth`google.cloud.logging.handlers.Transport.send`. Defaults to
         :class:`google.cloud.logging.handlers.BackgroundThreadTransport`. The other
         option is :class:`google.cloud.logging.handlers.SyncTransport`.
-    :type transport: :class:`type`
     :param resource: (Optional) Monitored resource of the entry, defaults
                      to the global resource type.
-    :type resource: :class:`~google.cloud.logging.resource.Resource`
     :param labels: (Optional) Mapping of labels for the entry.
-    :type labels: dict
     """
 
     LABEL_TASK_ID = "task_id"
@@ -86,29 +76,29 @@ class StackdriverTaskHandler(logging.Handler):
     LABEL_EXECUTION_DATE = "execution_date"
     LABEL_TRY_NUMBER = "try_number"
     LOG_VIEWER_BASE_URL = "https://console.cloud.google.com/logs/viewer"
-    LOG_NAME = 'Google Stackdriver'
+    LOG_NAME = "Google Stackdriver"
 
     def __init__(
         self,
-        gcp_key_path: Optional[str] = None,
-        scopes: Optional[Collection[str]] = _DEFAULT_SCOPESS,
+        gcp_key_path: str | None = None,
+        scopes: Collection[str] | None = _DEFAULT_SCOPESS,
         name: str = DEFAULT_LOGGER_NAME,
-        transport: Type[Transport] = BackgroundThreadTransport,
+        transport: type[Transport] = BackgroundThreadTransport,
         resource: Resource = _GLOBAL_RESOURCE,
-        labels: Optional[Dict[str, str]] = None,
+        labels: dict[str, str] | None = None,
     ):
         super().__init__()
-        self.gcp_key_path: Optional[str] = gcp_key_path
-        self.scopes: Optional[Collection[str]] = scopes
+        self.gcp_key_path: str | None = gcp_key_path
+        self.scopes: Collection[str] | None = scopes
         self.name: str = name
-        self.transport_type: Type[Transport] = transport
+        self.transport_type: type[Transport] = transport
         self.resource: Resource = resource
-        self.labels: Optional[Dict[str, str]] = labels
-        self.task_instance_labels: Optional[Dict[str, str]] = {}
-        self.task_instance_hostname = 'default-hostname'
+        self.labels: dict[str, str] | None = labels
+        self.task_instance_labels: dict[str, str] | None = {}
+        self.task_instance_hostname = "default-hostname"
 
     @cached_property
-    def _credentials_and_project(self) -> Tuple[Credentials, str]:
+    def _credentials_and_project(self) -> tuple[Credentials, str]:
         credentials, project = get_credentials_and_project_id(
             key_path=self.gcp_key_path, scopes=self.scopes, disable_logging=True
         )
@@ -121,7 +111,7 @@ class StackdriverTaskHandler(logging.Handler):
         client = gcp_logging.Client(
             credentials=credentials,
             project=project,
-            client_info=ClientInfo(client_library_version='airflow_v' + version.version),
+            client_info=CLIENT_INFO,
         )
         return client
 
@@ -131,7 +121,7 @@ class StackdriverTaskHandler(logging.Handler):
         credentials, _ = self._credentials_and_project
         client = LoggingServiceV2Client(
             credentials=credentials,
-            client_info=ClientInfo(client_library_version='airflow_v' + version.version),
+            client_info=CLIENT_INFO,
         )
         return client
 
@@ -146,10 +136,9 @@ class StackdriverTaskHandler(logging.Handler):
         """Actually log the specified logging record.
 
         :param record: The record to be logged.
-        :type record: logging.LogRecord
         """
         message = self.format(record)
-        labels: Optional[Dict[str, str]]
+        labels: dict[str, str] | None
         if self.labels and self.task_instance_labels:
             labels = {}
             labels.update(self.labels)
@@ -167,28 +156,23 @@ class StackdriverTaskHandler(logging.Handler):
         Configures the logger to add information with information about the current task
 
         :param task_instance: Currently executed task
-        :type task_instance:  :class:`airflow.models.TaskInstance`
         """
         self.task_instance_labels = self._task_instance_to_labels(task_instance)
         self.task_instance_hostname = task_instance.hostname
 
     def read(
-        self, task_instance: TaskInstance, try_number: Optional[int] = None, metadata: Optional[Dict] = None
-    ) -> Tuple[List[Tuple[Tuple[str, str]]], List[Dict[str, Union[str, bool]]]]:
+        self, task_instance: TaskInstance, try_number: int | None = None, metadata: dict | None = None
+    ) -> tuple[list[tuple[tuple[str, str]]], list[dict[str, str | bool]]]:
         """
         Read logs of given task instance from Stackdriver logging.
 
         :param task_instance: task instance object
-        :type task_instance: :class:`airflow.models.TaskInstance`
         :param try_number: task instance try_number to read logs from. If None
            it returns all logs
-        :type try_number: Optional[int]
         :param metadata: log metadata. It is used for steaming log reading and auto-tailing.
-        :type metadata: Dict
         :return: a tuple of (
             list of (one element tuple with two element tuple - hostname and logs)
             and list of metadata)
-        :rtype: Tuple[List[Tuple[Tuple[str, str]]], List[Dict[str, str]]]
         """
         if try_number is not None and try_number < 1:
             logs = f"Error fetching the logs. Try number {try_number} is invalid."
@@ -206,18 +190,18 @@ class StackdriverTaskHandler(logging.Handler):
 
         log_filter = self._prepare_log_filter(ti_labels)
         next_page_token = metadata.get("next_page_token", None)
-        all_pages = 'download_logs' in metadata and metadata['download_logs']
+        all_pages = "download_logs" in metadata and metadata["download_logs"]
 
         messages, end_of_log, next_page_token = self._read_logs(log_filter, next_page_token, all_pages)
 
-        new_metadata: Dict[str, Union[str, bool]] = {"end_of_log": end_of_log}
+        new_metadata: dict[str, str | bool] = {"end_of_log": end_of_log}
 
         if next_page_token:
-            new_metadata['next_page_token'] = next_page_token
+            new_metadata["next_page_token"] = next_page_token
 
         return [((self.task_instance_hostname, messages),)], [new_metadata]
 
-    def _prepare_log_filter(self, ti_labels: Dict[str, str]) -> str:
+    def _prepare_log_filter(self, ti_labels: dict[str, str]) -> str:
         """
         Prepares the filter that chooses which log entries to fetch.
 
@@ -226,7 +210,6 @@ class StackdriverTaskHandler(logging.Handler):
         https://cloud.google.com/logging/docs/view/advanced-queries
 
         :param ti_labels: Task Instance's labels that will be used to search for logs
-        :type: Dict[str, str]
         :return: logs filter
         """
 
@@ -239,25 +222,24 @@ class StackdriverTaskHandler(logging.Handler):
 
         _, project = self._credentials_and_project
         log_filters = [
-            f'resource.type={escale_label_value(self.resource.type)}',
+            f"resource.type={escale_label_value(self.resource.type)}",
             f'logName="projects/{project}/logs/{self.name}"',
         ]
 
         for key, value in self.resource.labels.items():
-            log_filters.append(f'resource.labels.{escape_label_key(key)}={escale_label_value(value)}')
+            log_filters.append(f"resource.labels.{escape_label_key(key)}={escale_label_value(value)}")
 
         for key, value in ti_labels.items():
-            log_filters.append(f'labels.{escape_label_key(key)}={escale_label_value(value)}')
+            log_filters.append(f"labels.{escape_label_key(key)}={escale_label_value(value)}")
         return "\n".join(log_filters)
 
     def _read_logs(
-        self, log_filter: str, next_page_token: Optional[str], all_pages: bool
-    ) -> Tuple[str, bool, Optional[str]]:
+        self, log_filter: str, next_page_token: str | None, all_pages: bool
+    ) -> tuple[str, bool, str | None]:
         """
         Sends requests to the Stackdriver service and downloads logs.
 
         :param log_filter: Filter specifying the logs to be downloaded.
-        :type log_filter: str
         :param next_page_token: The token of the page from which the log download will start.
             If None is passed, it will start from the first page.
         :param all_pages: If True is passed, all subpages will be downloaded. Otherwise, only the first
@@ -266,7 +248,6 @@ class StackdriverTaskHandler(logging.Handler):
             * string with logs
             * Boolean value describing whether there are more logs,
             * token of the next page
-        :rtype: Tuple[str, bool, str]
         """
         messages = []
         new_messages, next_page_token = self._read_single_logs_page(
@@ -289,24 +270,21 @@ class StackdriverTaskHandler(logging.Handler):
             end_of_log = not bool(next_page_token)
         return "\n".join(messages), end_of_log, next_page_token
 
-    def _read_single_logs_page(self, log_filter: str, page_token: Optional[str] = None) -> Tuple[str, str]:
+    def _read_single_logs_page(self, log_filter: str, page_token: str | None = None) -> tuple[str, str]:
         """
         Sends requests to the Stackdriver service and downloads single pages with logs.
 
         :param log_filter: Filter specifying the logs to be downloaded.
-        :type log_filter: str
         :param page_token: The token of the page to be downloaded. If None is passed, the first page will be
             downloaded.
-        :type page_token: str
         :return: Downloaded logs and next page token
-        :rtype: Tuple[str, str]
         """
         _, project = self._credentials_and_project
         request = ListLogEntriesRequest(
-            resource_names=[f'projects/{project}'],
+            resource_names=[f"projects/{project}"],
             filter=log_filter,
             page_token=page_token,
-            order_by='timestamp asc',
+            order_by="timestamp asc",
             page_size=1000,
         )
         response = self._logging_service_client.list_log_entries(request=request)
@@ -318,7 +296,7 @@ class StackdriverTaskHandler(logging.Handler):
         return "\n".join(messages), page.next_page_token
 
     @classmethod
-    def _task_instance_to_labels(cls, ti: TaskInstance) -> Dict[str, str]:
+    def _task_instance_to_labels(cls, ti: TaskInstance) -> dict[str, str]:
         return {
             cls.LABEL_TASK_ID: ti.task_id,
             cls.LABEL_DAG_ID: ti.dag_id,
@@ -345,11 +323,8 @@ class StackdriverTaskHandler(logging.Handler):
         """
         Creates an address for an external log collecting service.
         :param task_instance: task instance object
-        :type: task_instance: TaskInstance
         :param try_number: task instance try_number to read logs from.
-        :type try_number: Optional[int]
         :return: URL to the external log collection service
-        :rtype: str
         """
         _, project_id = self._credentials_and_project
 
@@ -359,10 +334,10 @@ class StackdriverTaskHandler(logging.Handler):
         log_filter = self._prepare_log_filter(ti_labels)
 
         url_query_string = {
-            'project': project_id,
-            'interval': 'NO_LIMIT',
-            'resource': self._resource_path,
-            'advancedFilter': log_filter,
+            "project": project_id,
+            "interval": "NO_LIMIT",
+            "resource": self._resource_path,
+            "advancedFilter": log_filter,
         }
 
         url = f"{self.LOG_VIEWER_BASE_URL}?{urlencode(url_query_string)}"
