@@ -16,18 +16,27 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google BigQuery Data Transfer Service operators."""
-from typing import TYPE_CHECKING, Optional, Sequence, Tuple, Union
+from __future__ import annotations
 
+from typing import TYPE_CHECKING, Sequence
+
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.bigquery_datatransfer_v1 import StartManualTransferRunsResponse, TransferConfig
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigquery_dts import BiqQueryDataTransferServiceHook, get_object_id
+from airflow.providers.google.cloud.links.bigquery_dts import BigQueryDataTransferConfigLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
+def _get_transfer_config_details(config_transfer_name: str):
+    config_details = config_transfer_name.split("/")
+    return {"project_id": config_details[1], "region": config_details[3], "config_id": config_details[5]}
+
+
 class BigQueryCreateDataTransferOperator(BaseOperator):
     """
     Creates a new data transfer configuration.
@@ -67,19 +76,20 @@ class BigQueryCreateDataTransferOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (BigQueryDataTransferConfigLink(),)
 
     def __init__(
         self,
         *,
         transfer_config: dict,
-        project_id: Optional[str] = None,
-        location: Optional[str] = None,
-        authorization_code: Optional[str] = None,
-        retry: Retry = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        location: str | None = None,
+        authorization_code: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id="google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -93,7 +103,7 @@ class BigQueryCreateDataTransferOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = BiqQueryDataTransferServiceHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain, location=self.location
         )
@@ -106,6 +116,16 @@ class BigQueryCreateDataTransferOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+
+        transfer_config = _get_transfer_config_details(response.name)
+        BigQueryDataTransferConfigLink.persist(
+            context=context,
+            task_instance=self,
+            region=transfer_config["region"],
+            config_id=transfer_config["config_id"],
+            project_id=transfer_config["project_id"],
+        )
+
         result = TransferConfig.to_dict(response)
         self.log.info("Created DTS transfer config %s", get_object_id(result))
         self.xcom_push(context, key="transfer_config_id", value=get_object_id(result))
@@ -152,13 +172,13 @@ class BigQueryDeleteDataTransferConfigOperator(BaseOperator):
         self,
         *,
         transfer_config_id: str,
-        project_id: Optional[str] = None,
-        location: Optional[str] = None,
-        retry: Retry = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        location: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id="google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -171,7 +191,7 @@ class BigQueryDeleteDataTransferConfigOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = BiqQueryDataTransferServiceHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain, location=self.location
         )
@@ -231,20 +251,21 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (BigQueryDataTransferConfigLink(),)
 
     def __init__(
         self,
         *,
         transfer_config_id: str,
-        project_id: Optional[str] = None,
-        location: Optional[str] = None,
-        requested_time_range: Optional[dict] = None,
-        requested_run_time: Optional[dict] = None,
-        retry: Retry = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        location: str | None = None,
+        requested_time_range: dict | None = None,
+        requested_run_time: dict | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id="google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -259,11 +280,11 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = BiqQueryDataTransferServiceHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain, location=self.location
         )
-        self.log.info('Submitting manual transfer for %s', self.transfer_config_id)
+        self.log.info("Submitting manual transfer for %s", self.transfer_config_id)
         response = hook.start_manual_transfer_runs(
             transfer_config_id=self.transfer_config_id,
             requested_time_range=self.requested_time_range,
@@ -273,8 +294,18 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+
+        transfer_config = _get_transfer_config_details(response.runs[0].name)
+        BigQueryDataTransferConfigLink.persist(
+            context=context,
+            task_instance=self,
+            region=transfer_config["region"],
+            config_id=transfer_config["config_id"],
+            project_id=transfer_config["project_id"],
+        )
+
         result = StartManualTransferRunsResponse.to_dict(response)
-        run_id = get_object_id(result['runs'][0])
+        run_id = get_object_id(result["runs"][0])
         self.xcom_push(context, key="run_id", value=run_id)
-        self.log.info('Transfer run %s submitted successfully.', run_id)
+        self.log.info("Transfer run %s submitted successfully.", run_id)
         return result
