@@ -15,7 +15,6 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains Google Vertex AI operators.
 
 .. spelling::
@@ -26,8 +25,9 @@
     aiplatform
     myVPC
 """
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.exceptions import NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -147,9 +147,9 @@ class CreateHyperparameterTuningJobOperator(BaseOperator):
     """
 
     template_fields = [
-        'region',
-        'project_id',
-        'impersonation_chain',
+        "region",
+        "project_id",
+        "impersonation_chain",
     ]
     operator_extra_links = (VertexAITrainingLink(),)
 
@@ -159,34 +159,34 @@ class CreateHyperparameterTuningJobOperator(BaseOperator):
         project_id: str,
         region: str,
         display_name: str,
-        metric_spec: Dict[str, str],
-        parameter_spec: Dict[str, hyperparameter_tuning._ParameterSpec],
+        metric_spec: dict[str, str],
+        parameter_spec: dict[str, hyperparameter_tuning._ParameterSpec],
         max_trial_count: int,
         parallel_trial_count: int,
         # START: CustomJob param
-        worker_pool_specs: Union[List[Dict], List[gapic.WorkerPoolSpec]],
-        base_output_dir: Optional[str] = None,
-        custom_job_labels: Optional[Dict[str, str]] = None,
-        custom_job_encryption_spec_key_name: Optional[str] = None,
-        staging_bucket: Optional[str] = None,
+        worker_pool_specs: list[dict] | list[gapic.WorkerPoolSpec],
+        base_output_dir: str | None = None,
+        custom_job_labels: dict[str, str] | None = None,
+        custom_job_encryption_spec_key_name: str | None = None,
+        staging_bucket: str | None = None,
         # END: CustomJob param
         max_failed_trial_count: int = 0,
-        search_algorithm: Optional[str] = None,
-        measurement_selection: Optional[str] = "best",
-        hyperparameter_tuning_job_labels: Optional[Dict[str, str]] = None,
-        hyperparameter_tuning_job_encryption_spec_key_name: Optional[str] = None,
+        search_algorithm: str | None = None,
+        measurement_selection: str | None = "best",
+        hyperparameter_tuning_job_labels: dict[str, str] | None = None,
+        hyperparameter_tuning_job_encryption_spec_key_name: str | None = None,
         # START: run param
-        service_account: Optional[str] = None,
-        network: Optional[str] = None,
-        timeout: Optional[int] = None,  # seconds
+        service_account: str | None = None,
+        network: str | None = None,
+        timeout: int | None = None,  # seconds
         restart_job_on_worker_restart: bool = False,
         enable_web_access: bool = False,
-        tensorboard: Optional[str] = None,
+        tensorboard: str | None = None,
         sync: bool = True,
         # END: run param
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -219,9 +219,9 @@ class CreateHyperparameterTuningJobOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None  # type: Optional[HyperparameterTuningJobHook]
+        self.hook: HyperparameterTuningJobHook | None = None
 
-    def execute(self, context: "Context"):
+    def execute(self, context: Context):
         self.log.info("Creating Hyperparameter Tuning job")
         self.hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
@@ -311,12 +311,12 @@ class GetHyperparameterTuningJobOperator(BaseOperator):
         region: str,
         project_id: str,
         hyperparameter_tuning_job_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -330,7 +330,7 @@ class GetHyperparameterTuningJobOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -379,12 +379,12 @@ class DeleteHyperparameterTuningJobOperator(BaseOperator):
         hyperparameter_tuning_job_id: str,
         region: str,
         project_id: str,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -398,7 +398,7 @@ class DeleteHyperparameterTuningJobOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context"):
+    def execute(self, context: Context):
         hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -458,16 +458,16 @@ class ListHyperparameterTuningJobOperator(BaseOperator):
         *,
         region: str,
         project_id: str,
-        page_size: Optional[int] = None,
-        page_token: Optional[str] = None,
-        filter: Optional[str] = None,
-        read_mask: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        page_size: int | None = None,
+        page_token: str | None = None,
+        filter: str | None = None,
+        read_mask: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -484,7 +484,7 @@ class ListHyperparameterTuningJobOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: "Context"):
+    def execute(self, context: Context):
         hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
