@@ -16,8 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google PubSub sensor."""
-import warnings
-from typing import TYPE_CHECKING, Any, Callable, List, Optional, Sequence, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Callable, Sequence
 
 from google.cloud.pubsub_v1.types import ReceivedMessage
 
@@ -49,23 +50,18 @@ class PubSubPullSensor(BaseSensorOperator):
     acknowledged before being returned, otherwise, downstream tasks will be
     responsible for acknowledging them.
 
-    ``project`` and ``subscription`` are templated so you can use
+    If you want a non-blocking task that does not to wait for messages, please use
+    :class:`~airflow.providers.google.cloud.operators.pubsub.PubSubPullOperator`
+    instead.
+
+    ``project_id`` and ``subscription`` are templated so you can use
     variables in them.
 
-    :param project: the Google Cloud project ID for the subscription (templated)
+    :param project_id: the Google Cloud project ID for the subscription (templated)
     :param subscription: the Pub/Sub subscription name. Do not include the
         full subscription path.
     :param max_messages: The maximum number of messages to retrieve per
         PubSub pull request
-    :param return_immediately:
-        (Deprecated) This is an underlying PubSub API implementation detail.
-        It has no real effect on Sensor behaviour other than some internal wait time before retrying
-        on empty queue.
-        The Sensor task will (by definition) always wait for a message, regardless of this argument value.
-
-        If you want a non-blocking task that does not to wait for messages, please use
-        :class:`~airflow.providers.google.cloud.operators.pubsub.PubSubPullOperator`
-        instead.
     :param ack_messages: If True, each message will be acknowledged
         immediately rather than by any downstream tasks
     :param gcp_conn_id: The connection ID to use connecting to
@@ -89,11 +85,11 @@ class PubSubPullSensor(BaseSensorOperator):
     """
 
     template_fields: Sequence[str] = (
-        'project_id',
-        'subscription',
-        'impersonation_chain',
+        "project_id",
+        "subscription",
+        "impersonation_chain",
     )
-    ui_color = '#ff7f50'
+    ui_color = "#ff7f50"
 
     def __init__(
         self,
@@ -101,36 +97,13 @@ class PubSubPullSensor(BaseSensorOperator):
         project_id: str,
         subscription: str,
         max_messages: int = 5,
-        return_immediately: bool = True,
         ack_messages: bool = False,
-        gcp_conn_id: str = 'google_cloud_default',
-        messages_callback: Optional[Callable[[List[ReceivedMessage], "Context"], Any]] = None,
-        delegate_to: Optional[str] = None,
-        project: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        messages_callback: Callable[[list[ReceivedMessage], Context], Any] | None = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
-        # To preserve backward compatibility
-        # TODO: remove one day
-        if project:
-            warnings.warn(
-                "The project parameter has been deprecated. You should pass the project_id parameter.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            project_id = project
-
-        if not return_immediately:
-            warnings.warn(
-                "The return_immediately parameter is deprecated.\n"
-                " It exposes what is really just an implementation detail of underlying PubSub API.\n"
-                " It has no effect on PubSubPullSensor behaviour.\n"
-                " It should be left as default value of True.\n"
-                " If is here only because of backwards compatibility.\n"
-                " If may be removed in the future.\n",
-                DeprecationWarning,
-                stacklevel=2,
-            )
 
         super().__init__(**kwargs)
         self.gcp_conn_id = gcp_conn_id
@@ -138,19 +111,18 @@ class PubSubPullSensor(BaseSensorOperator):
         self.project_id = project_id
         self.subscription = subscription
         self.max_messages = max_messages
-        self.return_immediately = return_immediately
         self.ack_messages = ack_messages
         self.messages_callback = messages_callback
         self.impersonation_chain = impersonation_chain
 
         self._return_value = None
 
-    def execute(self, context: "Context") -> Any:
+    def execute(self, context: Context) -> Any:
         """Overridden to allow messages to be passed"""
         super().execute(context)
         return self._return_value
 
-    def poke(self, context: "Context") -> bool:
+    def poke(self, context: Context) -> bool:
         hook = PubSubHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -161,7 +133,7 @@ class PubSubPullSensor(BaseSensorOperator):
             project_id=self.project_id,
             subscription=self.subscription,
             max_messages=self.max_messages,
-            return_immediately=self.return_immediately,
+            return_immediately=True,
         )
 
         handle_messages = self.messages_callback or self._default_message_callback
@@ -179,8 +151,8 @@ class PubSubPullSensor(BaseSensorOperator):
 
     def _default_message_callback(
         self,
-        pulled_messages: List[ReceivedMessage],
-        context: "Context",
+        pulled_messages: list[ReceivedMessage],
+        context: Context,
     ):
         """
         This method can be overridden by subclasses or by `messages_callback` constructor argument.
