@@ -26,8 +26,9 @@ from google.cloud.bigquery import DEFAULT_RETRY, ExtractJob
 
 from airflow import AirflowException
 from airflow.models import BaseOperator
-from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
+from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook, BigQueryJob
 from airflow.providers.google.cloud.links.bigquery import BigQueryTableLink
+from airflow.providers.google.cloud.triggers.bigquery import BigQueryInsertJobTrigger
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -79,11 +80,13 @@ class BigQueryToGCSOperator(BaseOperator):
     :param force_rerun: If True then operator will use hash of uuid as job id suffix
     :param reattach_states: Set of BigQuery job's states in case of which we should reattach
         to the job. Should be other than final states.
+    :param deferrable: Run operator in the deferrable mode
     """
 
     template_fields: Sequence[str] = (
         "source_project_dataset_table",
         "destination_cloud_storage_uris",
+        "export_format",
         "labels",
         "impersonation_chain",
     )
@@ -111,6 +114,7 @@ class BigQueryToGCSOperator(BaseOperator):
         job_id: str | None = None,
         force_rerun: bool = False,
         reattach_states: set[str] | None = None,
+        deferrable: bool = False,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -132,6 +136,7 @@ class BigQueryToGCSOperator(BaseOperator):
         self.force_rerun = force_rerun
         self.reattach_states: set[str] = reattach_states or set()
         self.hook: BigQueryHook | None = None
+        self.deferrable = deferrable
 
     @staticmethod
     def _handle_job_error(job: ExtractJob) -> None:
@@ -169,6 +174,24 @@ class BigQueryToGCSOperator(BaseOperator):
             configuration["extract"]["printHeader"] = self.print_header
         return configuration
 
+    def _submit_job(
+        self,
+        hook: BigQueryHook,
+        job_id: str,
+        configuration: dict,
+    ) -> BigQueryJob:
+        # Submit a new job without waiting for it to complete.
+
+        return hook.insert_job(
+            configuration=configuration,
+            project_id=hook.project_id,
+            location=self.location,
+            job_id=job_id,
+            timeout=self.result_timeout,
+            retry=self.result_retry,
+            nowait=True,
+        )
+
     def execute(self, context: Context):
         self.log.info(
             "Executing extract of %s into: %s",
@@ -195,15 +218,7 @@ class BigQueryToGCSOperator(BaseOperator):
 
         try:
             self.log.info("Executing: %s", configuration)
-            job: ExtractJob = hook.insert_job(
-                job_id=job_id,
-                configuration=configuration,
-                project_id=self.project_id,
-                location=self.location,
-                timeout=self.result_timeout,
-                retry=self.result_retry,
-            )
-            self._handle_job_error(job)
+            job: ExtractJob = self._submit_job(hook=hook, job_id=job_id, configuration=configuration)
         except Conflict:
             # If the job already exists retrieve it
             job = hook.get_job(
@@ -232,3 +247,30 @@ class BigQueryToGCSOperator(BaseOperator):
             project_id=project_id,
             table_id=table_id,
         )
+
+        if self.deferrable:
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=BigQueryInsertJobTrigger(
+                    conn_id=self.gcp_conn_id,
+                    job_id=job_id,
+                    project_id=self.hook.project_id,
+                ),
+                method_name="execute_complete",
+            )
+        else:
+            job.result(timeout=self.result_timeout, retry=self.result_retry)
+
+    def execute_complete(self, context: Context, event: dict[str, Any]):
+        """
+        Callback for when the trigger fires - returns immediately.
+        Relies on trigger to throw an exception, otherwise it assumes execution was
+        successful.
+        """
+        if event["status"] == "error":
+            raise AirflowException(event["message"])
+        self.log.info(
+            "%s completed with response %s ",
+            self.task_id,
+            event["message"],
+        )
